# Generated by roxygen2: do not edit by hand

export(antclassify)
export(antclassify_community)
export(assign_guild_ants)
export(check_endemic_atlantic_ants)
export(check_exotic_ants)
export(check_rarity_atlantic_ants)
export(validate_species_names)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(magrittr,"%>%")
importFrom(rlang,sym)
importFrom(scales,percent_format)
importFrom(stats,reorder)
importFrom(stringr,str_split_fixed)
importFrom(stringr,str_wrap)
importFrom(utils,URLencode)
importFrom(utils,head)
