#' Silva et al. (2015) Functional Guilds
#' @format A data frame with species and guild columns.
#' @source Silva, R. R., et al. (2015).
"silva_db"

#' Delabie et al. (2000) Functional Guilds
#' @format A data frame with genus and guild columns.
#' @source Delabie, J. H. C., et al. (2000).
"delabie_db"

#' AntClassify Generic Database
#' @format A data frame with genus and guild columns.
"generic_db"

#' Silvestre et al. (2003) Functional Guilds
#' @format A data frame with species/genus and guild columns.
#' @source Silvestre, R., et al. (2003).
"silvestre_db"


