#' Internal datasets used by AntClassify.
#'
#' @format Data frames
#' @keywords internal
"delabie_db"

#' @rdname delabie_db
"endemic_db"

#' @rdname delabie_db
"exotic_db"

#' @rdname delabie_db
"generic_db"

#' @rdname delabie_db
"rarity_db"

#' @rdname delabie_db
"silva_db"

#' @rdname delabie_db
"silvestre_db"

